Module signing

Module signing 

Modules

signable
Signable Trait

Structs

SecurePrivateKey
Secure wrapper for private key data that zeroizes on drop

Functions

load_private_key
Load a private key from a file path with automatic zeroization
pkey_to_secure
sign_data
Sign data with default SHA-384 algorithm
sign_data_with_algorithm
Sign data with a specific hash algorithm and automatic key zeroization
verify_signature
verify_signature_with_algorithm
Verify signature with a public key using the specified algorithm