pub fn sign_data_with_algorithm(
data: &[u8],
private_key: &SecurePrivateKey,
algorithm: &HashAlgorithm,
) -> Result<Vec<u8>>Expand description
Sign data with a specific hash algorithm and automatic key zeroization
pub fn sign_data_with_algorithm(
data: &[u8],
private_key: &SecurePrivateKey,
algorithm: &HashAlgorithm,
) -> Result<Vec<u8>>Sign data with a specific hash algorithm and automatic key zeroization