Modules
- signable
- Signable Trait
Structs
- Secure
Private Key - Secure wrapper for private key data that zeroizes on drop
Functions
- load_
private_ key - Load a private key from a file path with automatic zeroization
- pkey_
to_ secure - sign_
data - Sign data with default SHA-384 algorithm
- sign_
data_ with_ algorithm - Sign data with a specific hash algorithm and automatic key zeroization
- verify_
signature - verify_
signature_ with_ algorithm - Verify signature with a public key using the specified algorithm